## 0.0.54

This new version includes code refactoring for improved efficiency and cleaner console output.

### New Features

- None in this release

### Bug Fixes

- None in this release

### Refactoring

- Removed unnecessary progress task related to summarizing the paper in `zotero.py` (62c35b) (Eric Ma)
- Removed print statement indicating the completion of recording in `recorder.py` for cleaner console output (62c35b) (Eric Ma)

### Deprecations

- None in this release
